package com.ruoyi.project.system.service;

import com.ruoyi.project.system.domain.Product;
import com.ruoyi.project.system.domain.vo.FrontPriceVo;
import com.ruoyi.project.system.domain.vo.FrontProductVo;
import com.ruoyi.project.system.domain.vo.ProductVo;

import java.util.List;

/**
 * 商品Service接口
 *
 * @author zhu
 * @date 2023-10-24
 */
public interface IProductService {
    /**
     * 查询商品
     *
     * @param id 商品主键
     * @return 商品
     */
    public ProductVo selectProductById(Long id);

    /**
     * 查询商品列表
     *
     * @param product 商品
     * @return 商品集合
     */
    public List<Product> selectProductList(Product product);

    /**
     * 新增商品
     *
     * @param product 商品
     * @return 结果
     */
    public int insertProduct(Product product);

    /**
     * 修改商品
     *
     * @param product 商品
     * @return 结果
     */
    public int updateProduct(Product product);

    /**
     * 批量删除商品
     *
     * @param ids 需要删除的商品主键集合
     * @return 结果
     */
    public int deleteProductByIds(Long[] ids);

    /**
     * 删除商品信息
     *
     * @param id 商品主键
     * @return 结果
     */
    public int deleteProductById(Long id);

    /**
     * 计算商品价格
     *
     * @param frontProductVo
     * @return
     */
    public List<FrontPriceVo> compute(FrontProductVo frontProductVo);

    /**
     * 前端获取商品列表
     *
     * @param product
     * @return
     */
    public List<Product> selectFrontProductList(Product product);

}
